<?php
/*
Plugin Name: Pure Profiles
Description: This plugin connects to the Atira Pure API and pulls out the profile information, which it caches in local tables. Shortcodes can be used to display profile data. Currently supports basic HTTP authentication.
Author: Gavin Maxwell, HSS Web Team
Version: 1.4
Author URI: http://www.ed.ac.uk/schools-departments/humanities-soc-sci/information-for-staff/web-team
License: GPL2
*/
define('PURECLIENT_PATH', plugin_dir_path(__FILE__) );
require_once(PURECLIENT_PATH.'/libraries/guzzle.phar');
require_once(PURECLIENT_PATH.'/pure-profiles-admin-menu.php');
require_once(PURECLIENT_PATH.'/models/Person.class.php');
require_once(PURECLIENT_PATH.'/models/Project.class.php');
require_once(PURECLIENT_PATH.'/models/Publication.class.php');
require_once(PURECLIENT_PATH.'/models/Organisation.class.php');
use Guzzle\Http\Client;
	
register_activation_hook( __FILE__, 'pure_profiles_install' );

global $pure_profiles_db_version;
$pure_profiles_db_version = "1.4";

function pure_profiles_install() {
   global $wpdb;
   global $pure_profiles_db_version;

   $table_name = $wpdb->prefix . "pure_profiles_person";  
   $sql = "CREATE TABLE $table_name (
	  uuid varchar(40),
	  employeeid mediumint(9),
	  firstname tinytext NOT NULL,
	  lastname tinytext NOT NULL,	
	  callnamefirstname VARCHAR(255),
	  title VARCHAR (30),
	  photos TEXT,
	  retrieved varchar(30),	  
	  UNIQUE KEY uuid (uuid)
		);";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );
	
   $table_name = $wpdb->prefix . "pure_profiles_person_information";  
   $sql = "CREATE TABLE $table_name (
	  id int(9) NOT NULL AUTO_INCREMENT,
	  personuuid varchar(40),
	  title VARCHAR(255),
	  content TEXT,
	  retrieved varchar(30),	  
	  UNIQUE KEY id (id)
		);";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );	
	
	$table_name = $wpdb->prefix . "pure_profiles_organisation";  
	$sql = "CREATE TABLE $table_name (
	  uuid varchar(40),
	  organisationid VARCHAR(20),
	  organisationname tinytext NOT NULL,
	  organisationshortname tinytext NOT NULL,	  
	  typeclassificationid VARCHAR(255),
	  typeclassification VARCHAR(255) DEFAULT '' NOT NULL,
	  retrieved varchar(30),
	  UNIQUE KEY uuid (uuid)
		);";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );	
	
	$table_name = $wpdb->prefix . "pure_profiles_organisation_association";  
	$sql = "CREATE TABLE $table_name (
	  id int(9) NOT NULL AUTO_INCREMENT,
	  personuuid varchar(40),
	  employeeid mediumint(9),
	  organisationuuid VARCHAR(40),
	  organisationid VARCHAR(20),
	  organisationname TINYTEXT NOT NULL,
	  organisationshortname tinytext NOT NULL,	  
	  organisationtypeclassificationid VARCHAR(255),
	  organisationtypeclassification VARCHAR(255) DEFAULT '' NOT NULL,	  
	  employmenttypeid mediumint(9),
	  employmenttype VARCHAR(255),
	  retrieved varchar(30),	  
	  UNIQUE KEY id (id)
		);";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );		
	
	$table_name = $wpdb->prefix . "pure_profiles_staff_organisation_association";  
	$sql = "CREATE TABLE $table_name (
	  id int(9) NOT NULL AUTO_INCREMENT,
	  personuuid varchar(40),
	  employeeid mediumint(9),
	  organisationuuid VARCHAR(40),
	  jobdescription VARCHAR (255),
	  retrieved varchar(30),	  
	  UNIQUE KEY id (id)
		);";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );	
	
 	$table_name = $wpdb->prefix . "pure_profiles_project";  
	$sql = "CREATE TABLE $table_name (
	  uuid varchar(40),
	  title VARCHAR(255),
	  startdate VARCHAR(255),
	  finishdate VARCHAR(255),
	  projectstatusid VARCHAR(10),
	  projectstatus VARCHAR(255),
	  typeclassificationid VARCHAR(20),
	  typeclassification VARCHAR(255),
	  retrieved varchar(30),
	  UNIQUE KEY uuid (uuid)
		);";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );	
 
  	$table_name = $wpdb->prefix . "pure_profiles_project_person";  
	$sql = "CREATE TABLE $table_name (
	  id int(9) NOT NULL AUTO_INCREMENT,
	  personuuid varchar(40),
	  projectuuid varchar(40),
	  firstname VARCHAR(255),
	  lastname VARCHAR(255),
	  callname VARCHAR(255),
	  retrieved varchar(30),
	  UNIQUE KEY id (id)
		);";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );	
	
	$table_name = $wpdb->prefix . "pure_profiles_project_organisation";  
	$sql = "CREATE TABLE $table_name (
	  uuid varchar(40),
	  organisationid VARCHAR(50),
	  organisationname VARCHAR(255),
	  retrieved varchar(30),
	  UNIQUE KEY uuid (uuid)
		);";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );
 
 	$table_name = $wpdb->prefix . "pure_profiles_publication";  
	$sql = "CREATE TABLE $table_name (
	  uuid varchar(40),
	  title VARCHAR(255),
	  abstract TEXT,
	  originallanguage VARCHAR(50),
	  state VARCHAR(50),
	  dois TEXT,
	  numberofpages VARCHAR(50),
	  personuuid varchar(40),
	  publicationyear varchar(10),
	  publicationmonth varchar(10),
	  publicationday varchar(10),
	  volume VARCHAR(255),
	  journalnumber VARCHAR(50),
	  journalpages VARCHAR(255),
	  journaltitle VARCHAR(255),
	  journalissn VARCHAR(255),
	  retrieved varchar(30),
	  UNIQUE KEY uuid (uuid)
		);";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );	
	
	$table_name = $wpdb->prefix . "pure_profiles_publication_person";  
	$sql = "CREATE TABLE $table_name (
	  id int(9) NOT NULL AUTO_INCREMENT,
	  personuuid varchar(40),
	  publicationuuid VARCHAR(40),
	  title VARCHAR(255),
	  firstname VARCHAR(255),
	  lastname VARCHAR(255),
	  personrole VARCHAR(255),
	  retrieved varchar(30),	  
	  UNIQUE KEY id (id)
		);";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql );			
 
	add_option( "pure_profiles_db_version", $pure_profiles_db_version );
}
$person = new Person();
$person->schedule_request();
function my_activation() {
	$basehour = get_option('pure_profiles_cron_basehour_settings');
	$recurrence = get_option('pure_profiles_cron_recurrence_settings');
	
	if ( !wp_next_scheduled( 'pure_profiles_request_api_event' ) ) {
		wp_schedule_event( strtotime($basehour.":00"), ''.$recurrence.'', 'pure_profiles_request_api_event');
	}
}
add_action('wp', 'my_activation');


/* shortcodes */
function register_shortcodes(){
	add_shortcode("pureprofiles","pure_profiles_parse");
}
function pure_profiles_parse($atts) {
	global $wpdb;
	extract(shortcode_atts(array(
      'employeeid' => -1,
	  'hide' => ''
	), $atts));
	
	$str = "";
	/* get profiles by employeeid */
	if ($employeeid == -1) {
		$persons = $wpdb->get_results( "SELECT * FROM " . $wpdb->prefix . "pure_profiles_person" );
	} else {
		$persons = $wpdb->get_results( "SELECT * FROM " . $wpdb->prefix . "pure_profiles_person WHERE employeeid=" .$employeeid);
	}

	/* decide which sections to show */
	$hide_profile_information = FALSE;
	$hide_publications = FALSE;
	$hide_projects = FALSE;
	if (trim($hide) != '') {
		if (strpos($hide, 'profileinformation') !== FALSE) $hide_profile_information = "yes";
		if (strpos($hide, 'publications') !== FALSE) $hide_publications = "yes";
		if (strpos($hide, 'projects') !== FALSE) $hide_projects = "yes";
	} 
	
	$str.= "<div class='pure-profiles-wrapper'>";
	foreach ($persons as $p) {
		if ($person->callnamefirstname != "") {
			$the_first_name = $person->callnamefirstname;
		} else {
			$the_first_name = $p->firstname;
		}
		$str.= "<span class='pure-profiles-header'>".$p->title." ".$the_first_name." ".$p->lastname."</span>";
		
		$str.= "<div class='pure-profiles-body'>";
		
		$organisations = $wpdb->get_results( "SELECT * FROM " . $wpdb->prefix . "pure_profiles_organisation_association WHERE personuuid='" . $p->uuid ."'");
		foreach ($organisations as $o) {
			$str.= "<span class='organisation-name'>".$o->organisationname."</span>";
			$staff_organisations = $wpdb->get_results( "SELECT * FROM " . $wpdb->prefix . "pure_profiles_staff_organisation_association " .
													"WHERE personuuid='" . $p->uuid ."' AND organisationuuid='".$o->organisationuuid."'");
			foreach ($staff_organisations as $so) {
				$str.= "<span class='job-description'> - ".$so->jobdescription."</span><br/>";
			}	
			//$str.= $o->employmenttype."<br/>";

		}
		$str.= "</div><br/>";
		
		if ($hide_profile_information != "yes") {
	
			$photos = explode(",", $p->photos);
			foreach ($photos as $phot) {
				if (trim($phot) != "") {
					$str.= "<img src='".plugins_url($phot, __FILE__ )."' class='pure-profiles-photo'>";
				}
			}
			$str.= "<br/>";
			
			$profile_information = $wpdb->get_results( "SELECT * FROM " . $wpdb->prefix . "pure_profiles_person_information WHERE personuuid='" . $p->uuid ."'");
			foreach ($profile_information as $pi) {
				$str.= "<span class='pure-profiles-information-title'>".$pi->title."</span><br/>";
				$str.= $pi->content;
			}
		} // if !$hide_profile_information
		
		if ($hide_publications != "yes") {
			$publications = $wpdb->get_results( "SELECT * FROM " . $wpdb->prefix . "pure_profiles_publication WHERE personuuid='" . $p->uuid . "' ORDER BY publicationyear DESC");
			$str.= "<span class='pure-profiles-publications-header'>Publications:</span>";
			$str.= "<div class='pure-profiles-publications-body'>";
			$current_year = "";
			foreach ($publications as $pub) {
				if ($current_year != $pub->publicationyear) {
					$current_year = $pub->publicationyear;
					$str.= "<div class='pure-profiles-publication-year'>".$current_year."</div>";
				}
				$str.= "<span class='pure-profiles-publication-title'>".$pub->title."</span><br/>";
				$str.= "<span class='pure-profiles-publication-info'>";
				$authors_str = "";
				$authors = $wpdb->get_results( "SELECT * FROM " . $wpdb->prefix . "pure_profiles_publication_person WHERE publicationuuid='" . $pub->uuid . "' AND personrole='Author'");
				$num_authors = count($authors);
				for ($i=0; $i < $num_authors; $i++) {
					$authors_str.= $authors[$i]->lastname.", ".$authors[$i]->firstname;
					if (($i == ($num_authors-2)) && ($num_authors > 1)) {
						$authors_str.= " & ";
					}elseif ($i == ($num_authors-1)) {
						$authors_str.= ". ";
					} else {
						$authors_str.= ", ";
					}
				}
				$str.= $authors_str;
				
				$publication_date = "";
				if ($pub->publicationday != "") $publication_date .= $pub->publicationday."-";
				$months = array('','Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec');
				if ($pub->publicationmonth != "") $publication_date .= $months[(int)$pub->publicationmonth]."-";
				if ($pub->publicationyear != "") $publication_date .= $pub->publicationyear;
				$str.= " ".$publication_date." ";
				
				if ($pub->journaltitle != "") {
					$str.= " In : ".$pub->journaltitle.". ";
				}
				
				$str.= "</span><br/>";
			}
			$str.= "</div><br/>";
		} // end if !$hide_publications
		
		if ($hide_projects != "yes") {
			$projects = $wpdb->get_results( "SELECT * FROM " . $wpdb->prefix . "pure_profiles_project ppp, " . 
				$wpdb->prefix . "pure_profiles_project_person pppp WHERE pppp.personuuid='" . $p->uuid . "' AND ppp.uuid=pppp.projectuuid");
			if (count($projects) > 0) {
				$str.= "<span class='pure-profiles-projects-header'>Projects:</span>";
				$str.= "<div class='pure-profiles-projects-body'>";
				foreach ($projects as $proj) {
					$str.= "<span class='pure-profiles-project-title'>".$proj->title."</span><br/>";
					$project_persons = $wpdb->get_results( "SELECT * FROM " . $wpdb->prefix . "pure_profiles_project_person WHERE projectuuid='" . $proj->uuid . "'");
					for ($pp = 0; $pp < count($project_persons); $pp++) {
						$str.= $project_persons[$pp]->lastname.", ".$project_persons[$pp]->callname.", ";
					}
					$str.= "<br/>";
					$start_date = date("j/m/Y", strtotime($proj->startdate));
					$end_date = date("j/m/Y", strtotime($proj->finishdate));
					$str.= "<span class='pure-profiles-project-info'>".$start_date."<abbr class='pure-profiles-project-period-arrow' title='to'>&ndash;</abbr>".$end_date."</span><br/>";
				}
				$str.= "</div><br/>";
			}
		} // end if !$hide_projects
	}
	$str.= "</div>";
	return $str;
}
add_action( 'init', 'register_shortcodes');

/* shortcode button for TinyMCE */
 add_action('init', 'pure_profiles_shortcode_button_init');
 function pure_profiles_shortcode_button_init() {

      //Abort early if the user will never see TinyMCE
      if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') && get_user_option('rich_editing') == 'true')
           return;

      add_filter("mce_external_plugins", "pure_profiles_register_tinymce_plugin"); 
      add_filter('mce_buttons', 'pure_profiles_add_tinymce_button');
	  
}

/* This callback registers the plug-in */
function pure_profiles_register_tinymce_plugin($plugin_array) {
    $plugin_array['pure_profiles_button'] = plugins_url('/libraries/tinymce/pureprofiles.js', __FILE__);
    return $plugin_array;
}

/* This callback adds the button to the toolbar */
function pure_profiles_add_tinymce_button($buttons) {
    $buttons[] = "pure_profiles_button";
    return $buttons;
}


/* add CSS */
$options = get_option('pure_profiles_options');
$enable_styles = htmlentities ( $options['pure_profiles_enable_styles_settings'], ENT_QUOTES );
if ($enable_styles == "yes") {
	add_action('init', 'pure_profiles_register_style');
	function pure_profiles_register_style(){
		wp_register_style( 'pure_profile_styles', plugins_url('/styles.css', __FILE__));
	}
	add_action('wp_enqueue_scripts', 'pure_profiles_enqueue_style');
	function pure_profiles_enqueue_style(){
		wp_enqueue_style( 'pure_profile_styles' );
	}
}

/*
function tl_save_error() {
    update_option( 'plugin_error',  ob_get_contents() );
}
add_action( 'activated_plugin', 'tl_save_error' );
*/
